Index: src/vm/signal.h |
diff --git a/src/vm/signal.h b/src/vm/signal.h |
index 4ffe4a829ac8f7f24af51afbe059190f2040ec5a..a16e76d9db4304ed9c31660cfa0edc112c77a1d3 100644 |
--- a/src/vm/signal.h |
+++ b/src/vm/signal.h |
@@ -13,11 +13,11 @@ |
#include "src/vm/port.h" |
#include "src/vm/process_handle.h" |
-namespace fletch { |
+namespace dartino { |
class Signal : public Refcounted<Signal> { |
public: |
// Please keep these in sync with lib/fletch/fletch.dart:SignalKind. |
enum Kind { |
kCompileTimeError, |
kTerminated, |
@@ -45,6 +45,6 @@ class Signal : public Refcounted<Signal> { |
const Kind kind_; |
}; |
-} // namespace fletch |
+} // namespace dartino |
#endif // SRC_VM_SIGNAL_H_ |
@@ -13,11 +13,11 @@ |
class Signal : public Refcounted<Signal> { |
public: |
- // Please keep these in sync with lib/fletch/fletch.dart:SignalKind. |
+ // Please keep these in sync with lib/dartino/dartino.dart:SignalKind. |
enum Kind { |
kCompileTimeError, |